.. SPDX-FileCopyrightText: 2025 icalendar-anonymizer contributors
.. SPDX-License-Identifier: AGPL-3.0-or-later

=============
API Reference
=============

.. toctree::
   :maxdepth: 2

   anonymizer
   config
   version
